Changelog
=========

0.3 (unreleased)
----------------
-

0.2 (2117-11-19)
----------------
- setup travis
- set clipboad only when TOTP has been changed
- fix readme.rst to make cleaner on pypi

0.1 (2017-11-11)
----------------
- Initial implementation
